"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertPrimaryColorsToString = exports.rgbToHsl = exports.getFilterValuesFromExpression = exports.isFunction = exports.getPreferredColorScheme = exports.getQuestionTypes = exports.stringify = exports.stringifyWithDefaults = exports.defaultOnQuizResultsLoadedCode = exports.defaultOnQuizResultClickCode = exports.defaultOnAddToCartClickCode = exports.getStoryParams = exports.renderImages = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const actions_1 = require("./components/CioQuiz/actions");
const renderImages = (images, cssClasses) => {
    const { primary_url: primaryUrl, primary_alt: primaryAlt, secondary_url: secondaryUrl, secondary_alt: secondaryAlt, } = images;
    if (primaryUrl) {
        const windowWidth = window.innerWidth;
        let src = primaryUrl;
        let alt = primaryAlt || 'Quiz Image';
        if (windowWidth > 768 && secondaryUrl) {
            src = secondaryUrl;
            if (secondaryAlt) {
                alt = secondaryAlt;
            }
        }
        return (react_1.default.createElement("span", { className: `${cssClasses || ''}`.trim() },
            react_1.default.createElement("img", { className: 'cio-question-image', src: src, alt: alt })));
    }
    return '';
};
exports.renderImages = renderImages;
// More on Story layout: https://storybook.js.org/docs/react/configure/story-layout
const getStoryParams = (storyCode, templateCode, importCode) => {
    const code = `
${importCode}
${storyCode}
${templateCode}
`;
    return {
        docs: {
            source: {
                code,
                language: 'jsx',
                format: true,
                type: 'code',
            },
        },
    };
};
exports.getStoryParams = getStoryParams;
exports.defaultOnAddToCartClickCode = `"onAddToCartClick": (item) => console.dir(item)`;
exports.defaultOnQuizResultClickCode = `"onQuizResultClick": (result, position) => console.dir(result, position)`;
exports.defaultOnQuizResultsLoadedCode = `"onQuizResultsLoaded": (results) => console.dir(results)`;
const stringifyWithDefaults = (obj) => {
    const { resultsPageOptions, cioJsClient } = obj, rest = tslib_1.__rest(obj, ["resultsPageOptions", "cioJsClient"]);
    const { onAddToCartClick, onQuizResultsLoaded, onQuizResultClick } = resultsPageOptions;
    let res = JSON.stringify(Object.assign(Object.assign({}, rest), { resultsPageOptions }), null, '  ');
    if (cioJsClient) {
        res = res.replace('"resultsPageOptions": {', `"cioJsClient": cioJsClient,
  "resultsPageOptions": {`);
    }
    if (onQuizResultsLoaded) {
        res = res.replace('"resultsPageOptions": {', `"resultsPageOptions": {
    ${exports.defaultOnQuizResultsLoadedCode},`);
    }
    if (onQuizResultClick) {
        res = res.replace('"resultsPageOptions": {', `"resultsPageOptions": {
    ${exports.defaultOnQuizResultClickCode},`);
    }
    if (onAddToCartClick) {
        res = res.replace('"resultsPageOptions": {', `"resultsPageOptions": {
    ${exports.defaultOnAddToCartClickCode},`);
    }
    return res;
};
exports.stringifyWithDefaults = stringifyWithDefaults;
const stringify = (obj) => JSON.stringify(obj, null, '  ');
exports.stringify = stringify;
const getQuestionTypes = (questionType) => {
    const isOpenQuestion = questionType === actions_1.QuestionTypes.OpenText;
    const isCoverQuestion = questionType === actions_1.QuestionTypes.Cover;
    const isSingleQuestion = questionType === actions_1.QuestionTypes.SingleSelect;
    const isMultipleQuestion = questionType === actions_1.QuestionTypes.MultipleSelect;
    const isSelectQuestion = isSingleQuestion || isMultipleQuestion;
    return {
        isOpenQuestion,
        isCoverQuestion,
        isSingleQuestion,
        isMultipleQuestion,
        isSelectQuestion,
    };
};
exports.getQuestionTypes = getQuestionTypes;
function getPreferredColorScheme() {
    var _a;
    let colorScheme = 'light';
    // Check if the dark-mode Media-Query matches
    if ((_a = window.matchMedia('(prefers-color-scheme: dark)')) === null || _a === void 0 ? void 0 : _a.matches) {
        colorScheme = 'dark';
    }
    return colorScheme;
}
exports.getPreferredColorScheme = getPreferredColorScheme;
function isFunction(fn) {
    return fn && typeof fn === 'function';
}
exports.isFunction = isFunction;
const isValueExpression = (exp) => 'name' in exp && 'value' in exp;
const isAndFilter = (exp) => 'and' in exp;
const isOrFilter = (exp) => 'or' in exp;
const getFilterValuesFromExpression = (exp) => {
    if (!exp) {
        return [];
    }
    if (isAndFilter(exp)) {
        return exp.and.flatMap((innerExpression) => (0, exports.getFilterValuesFromExpression)(innerExpression));
    }
    if (isOrFilter(exp)) {
        return exp.or.flatMap((innerExpression) => (0, exports.getFilterValuesFromExpression)(innerExpression));
    }
    if (isValueExpression(exp)) {
        return [exp.value];
    }
    return [];
};
exports.getFilterValuesFromExpression = getFilterValuesFromExpression;
function rgbToHsl(r, g, b) {
    const rConverted = r / 255;
    const gConverted = g / 255;
    const bConverted = b / 255;
    const max = Math.max(rConverted, gConverted, bConverted);
    const min = Math.min(rConverted, gConverted, bConverted);
    const delta = max - min;
    let h = 0;
    if (delta === 0)
        h = 0;
    else if (max === rConverted)
        h = ((gConverted - bConverted) / delta) % 6;
    else if (max === gConverted)
        h = (bConverted - rConverted) / delta + 2;
    else if (max === bConverted)
        h = (rConverted - gConverted) / delta + 4;
    const l = (min + max) / 2;
    const s = delta === 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
    const finalH = Math.round(h * 60);
    const finalS = Math.round(s * 100);
    const finalL = Math.round(l * 100);
    return [finalH, finalS, finalL];
}
exports.rgbToHsl = rgbToHsl;
function convertPrimaryColorsToString(primaryColorStyles) {
    return `{
    --primary-color-h: ${primaryColorStyles['--primary-color-h']}; 
    --primary-color-s: ${primaryColorStyles['--primary-color-s']}; 
    --primary-color-l: ${primaryColorStyles['--primary-color-l']}; 
  }`;
}
exports.convertPrimaryColorsToString = convertPrimaryColorsToString;
