import React, { useContext, useEffect, useState } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import { renderImages } from '../../utils';
import QuizContext from '../CioQuiz/context';
import ControlBar from '../ControlBar/ControlBar';
function OpenTextQuestion(props) {
    const { initialValue = '', onChangeHandler: userDefinedHandler = null } = props;
    const { state, previousQuestion, nextQuestion } = useContext(QuizContext);
    const [openTextInput, setOpenTextInput] = useState(initialValue);
    let question;
    if (state?.quiz.currentQuestion) {
        question = state?.quiz.currentQuestion.next_question;
    }
    const onChangeHandler = (e) => {
        setOpenTextInput(e.target.value);
        if (userDefinedHandler) {
            userDefinedHandler(e);
        }
    };
    const onNextClick = () => {
        if (nextQuestion && openTextInput) {
            nextQuestion(openTextInput);
        }
    };
    const onKeyDownHandler = (e) => {
        const { key } = e;
        if (key === 'Enter') {
            onNextClick();
        }
    };
    useEffect(() => {
        if (state?.quiz.currentQuestion) {
            const questionId = state?.quiz.currentQuestion?.next_question.id;
            const currentAnswer = state.answers.inputs?.[questionId];
            const openTextAnswer = currentAnswer || initialValue;
            setOpenTextInput(openTextAnswer);
        }
    }, [state, initialValue]);
    if (question) {
        const hasImage = question?.images?.primary_url;
        return (React.createElement("div", { className: `
          cio-container${hasImage ? '--with-image' : ''}
          cio-open-text-question-container${hasImage ? '--with-image' : ''}
        `, "data-question-key": question.key },
            hasImage ? renderImages(question.images, 'cio-question-image-container') : '',
            React.createElement("div", { className: 'cio-question-content' },
                React.createElement(QuestionTitle, { title: question.title }),
                React.createElement(QuestionDescription, { description: question.description }),
                React.createElement("input", { className: 'cio-question-input-text', placeholder: question.input_placeholder || 'Answer here...', value: openTextInput, onChange: onChangeHandler, onKeyDown: onKeyDownHandler }),
                React.createElement(ControlBar, { nextButtonHandler: onNextClick, isNextButtonDisabled: !openTextInput, backButtonHandler: previousQuestion, showBackButton: !state?.quiz.isFirstQuestion, ctaButtonText: question?.cta_text }))));
    }
    return null;
}
export default OpenTextQuestion;
